==> brmo-stufbg204-1.5.1-sources.jar: nl/egem/stuf/stuf0204/TijdvakGeldigheid.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TijdvakGeldigheid complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TijdvakGeldigheid">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="begindatumTijdvakGeldigheid" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicator"/>
 *         &lt;element name="einddatumTijdvakGeldigheid" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicator"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TijdvakGeldigheid", propOrder = {
    "begindatumTijdvakGeldigheid",
    "einddatumTijdvakGeldigheid"
})
public class TijdvakGeldigheid {

    @XmlElement(required = true, nillable = true)
    protected DatumMetIndicator begindatumTijdvakGeldigheid;
    @XmlElement(required = true, nillable = true)
    protected DatumMetIndicator einddatumTijdvakGeldigheid;

    /**
     * Gets the value of the begindatumTijdvakGeldigheid property.
     * 
     * @return
     *     possible object is
     *     {@link DatumMetIndicator }
     *     
     */
    public DatumMetIndicator getBegindatumTijdvakGeldigheid() {
        return begindatumTijdvakGeldigheid;
    }

    /**
     * Sets the value of the begindatumTijdvakGeldigheid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DatumMetIndicator }
     *     
     */
    public void setBegindatumTijdvakGeldigheid(DatumMetIndicator value) {
        this.begindatumTijdvakGeldigheid = value;
    }

    /**
     * Gets the value of the einddatumTijdvakGeldigheid property.
     * 
     * @return
     *     possible object is
     *     {@link DatumMetIndicator }
     *     
     */
    public DatumMetIndicator getEinddatumTijdvakGeldigheid() {
        return einddatumTijdvakGeldigheid;
    }

    /**
     * Sets the value of the einddatumTijdvakGeldigheid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DatumMetIndicator }
     *     
     */
    public void setEinddatumTijdvakGeldigheid(DatumMetIndicator value) {
        this.einddatumTijdvakGeldigheid = value;
    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/stuf0204/TijdvakGeldigheid.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TijdvakGeldigheid complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TijdvakGeldigheid"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="begindatumTijdvakGeldigheid" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicator"/&gt;
 *         &lt;element name="einddatumTijdvakGeldigheid" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicator"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TijdvakGeldigheid", propOrder = {
    "begindatumTijdvakGeldigheid",
    "einddatumTijdvakGeldigheid"
})
public class TijdvakGeldigheid {

    @XmlElement(required = true, nillable = true)
    protected DatumMetIndicator begindatumTijdvakGeldigheid;
    @XmlElement(required = true, nillable = true)
    protected DatumMetIndicator einddatumTijdvakGeldigheid;

    /**
     * Gets the value of the begindatumTijdvakGeldigheid property.
     * 
     * @return
     *     possible object is
     *     {@link DatumMetIndicator }
     *     
     */
    public DatumMetIndicator getBegindatumTijdvakGeldigheid() {
        return begindatumTijdvakGeldigheid;
    }

    /**
     * Sets the value of the begindatumTijdvakGeldigheid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DatumMetIndicator }
     *     
     */
    public void setBegindatumTijdvakGeldigheid(DatumMetIndicator value) {
        this.begindatumTijdvakGeldigheid = value;
    }

    /**
     * Gets the value of the einddatumTijdvakGeldigheid property.
     * 
     * @return
     *     possible object is
     *     {@link DatumMetIndicator }
     *     
     */
    public DatumMetIndicator getEinddatumTijdvakGeldigheid() {
        return einddatumTijdvakGeldigheid;
    }

    /**
     * Sets the value of the einddatumTijdvakGeldigheid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DatumMetIndicator }
     *     
     */
    public void setEinddatumTijdvakGeldigheid(DatumMetIndicator value) {
        this.einddatumTijdvakGeldigheid = value;
    }

}
